# Generated by Django 2.0.13 on 2019-03-15 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('andablog', '0006_auto_20170609_1759'),
    ]

    operations = [
        migrations.AddField(
            model_name='entry',
            name='content_markup_type',
            field=models.CharField(choices=[('', '--'), ('html', 'HTML'), ('plain', 'Plain'), ('markdown', 'Markdown'), ('restructuredtext', 'Restructured Text')], default='markdown', max_length=30),
        ),
        migrations.AddField(
            model_name='entry',
            name='preview_content_markup_type',
            field=models.CharField(choices=[('', '--'), ('html', 'HTML'), ('plain', 'Plain'), ('markdown', 'Markdown'), ('restructuredtext', 'Restructured Text')], default='markdown', max_length=30),
        ),
        migrations.AlterField(
            model_name='entry',
            name='_content_rendered',
            field=models.TextField(editable=False),
        ),
        migrations.AlterField(
            model_name='entry',
            name='_preview_content_rendered',
            field=models.TextField(editable=False),
        ),
    ]
